<p align="center"> <img src="https://raw.githubusercontent.com/mooncell07/reChip8/master/docs/img/reChip8.png" height=100> </p>

<h1 align="center"> <a href="https://mooncell07.github.io/reChip8/">reChip8</a> </h1>
<h2 align="center">
<img alt="Stargazers" src="https://img.shields.io/github/stars/mooncell07/reChip8?style=for-the-badge&logo=starship&color=C9CBFF&logoColor=D9E0EE&labelColor=302D41">
<img alt="Issues" src="https://img.shields.io/github/issues/mooncell07/reChip8?style=for-the-badge&logo=gitbook&color=B5E8E0&logoColor=D9E0EE&labelColor=302D41">
<img alt="Releases" src="https://img.shields.io/github/license/mooncell07/reChip8?style=for-the-badge&logo=github&color=F2CDCD&logoColor=D9E0EE&labelColor=302D41"/>
</h2>

re:Chip8 (Formerly: Lemon.pie) is a **[CHIP-8](https://en.wikipedia.org/wiki/CHIP-8)** Emulator written in Python using Pygame.
This project aims at implementing the classic variant of CHIP-8 Virtual Machine. Currently a Work in Progress.

## Demo

![CHIP-8 Logo](https://raw.githubusercontent.com/mooncell07/reChip8/master/docs/img/chip8-logo.png)

![PONG](https://raw.githubusercontent.com/mooncell07/reChip8/master/docs/img/gameplay-pong.png)

![Animal Race](https://raw.githubusercontent.com/mooncell07/reChip8/master/docs/img/gameplay-animal-race.png)

Usage and more info is available on [reChip8](https://mooncell07.github.io/reChip8/).
